==> haskell-doctest-0.16.0.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.16.0.1
id: doctest-0.16.0.1-FXJUFtOapkrFB6wRkLTqsN
key: doctest-0.16.0.1-FXJUFtOapkrFB6wRkLTqsN
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: 17783f032824b4ca8337b3b1bd694214
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.6.5/site-local/doctest-0.16.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doctest-0.16.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/doctest-0.16.0.1
hs-libraries: HSdoctest-0.16.0.1-FXJUFtOapkrFB6wRkLTqsN
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 ghc-8.6.5
    ghc-paths-0.1.0.9-KaBYbRV3ryA10w04FwbrO2 process-1.6.5.0
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.16.0.1-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctest
version: 0.16.0.1
id: doctest-0.16.0.1-Cj94t9XvgcBJWkN7jFtUx3
key: doctest-0.16.0.1-Cj94t9XvgcBJWkN7jFtUx3
license: MIT
copyright: (c) 2009-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/doctest#readme
synopsis: Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<http://docs.python.org/library/doctest.html>).
    .
    Documentation is at <https://github.com/sol/doctest#readme>.
category: Testing
abi: 84bbc8e17dc31e009ebc598b484f7aad
exposed: True
exposed-modules:
    Test.DocTest
hidden-modules: Extract GhcUtil Interpreter Location Options
                PackageDBs Parse Property Run Runner Runner.Example Sandbox Util
                Language.Haskell.GhciWrapper Paths_doctest
import-dirs: /usr/lib/ghc-8.6.5/site-local/doctest-0.16.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/doctest-0.16.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/doctest-0.16.0.1
hs-libraries: HSdoctest-0.16.0.1-Cj94t9XvgcBJWkN7jFtUx3
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    code-page-0.2-3TjNtc9lu3RJN6poyFdQXs deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 ghc-8.6.5
    ghc-paths-0.1.0.9-KaBYbRV3ryA10w04FwbrO2 process-1.6.5.0
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html: /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
